
<h1 align="center">
    <span style="color:#FFA566">⚙️DM</span>DD<span style="color:#FFA566">L⚙️</span>
</h1>
<div align="center">
    <a href = "https://opensource.org/licenses/MIT">
    <img  src="https://img.shields.io/badge/License-MIT-yellow.svg">
    </a>
</div>
<img src=".github/dmddl%20logo_3.png" align="center">

<h3 align="center">
    CLI app that generates insertion script from DDL
</h3>

---
<h2>
    🖥 Installation
</h2>
